require(reshape2)
require(ggplot2)
require(foreign)
require(lme4)
require(languageR)

setwd("/Users/analysis")

temp<-read.spss("Expected_andexperienced_usability.sav", to.data.frame=TRUE, use.value.labels=FALSE)

names(temp)
attach(temp)

data<-data.frame(VP, Web1Ä, response_.1.1, response_.1.2, response_.1.3, A1, B1, Bearb1, WWU1_mean, Web7Ä, response_.7.1, response_.7.2, response_.7.3, A7, B7, Bearb7, WWU7_mean, Web12Ä, response_.12.1, response_.12.2, response_.12.3, A12, B12, Bearb12, WWU12_mean, Web20Ä, response_.20.1, response_.20.2, response_.20.3, A20, B20, Bearb20, WWU20_mean, Web24Ä, response_.24.1, response_.24.2, response_.24.3, A24, B24, Bearb24, WWU24_mean, Web27Ä, response_.27.1, response_.27.2, response_.27.3, A27, B27, Bearb27, WWU27_mean, Web31Ä, response_.31.1, response_.31.2, response_.31.3, A31, B31, Bearb31, WWU31_mean, Web39Ä, response_.39.1, response_.39.2, response_.39.3, A39, B39, Bearb39, WWU39_mean, Web45Ä, response_.45.1, response_.45.2, response_.45.3, A45, B45, Bearb45, WWU45_mean, Web48Ä, response_.48.1, response_.48.2, response_.48.3, A48, B48, Bearb48, WWU48_mean)



tmp<-melt(data, id=c("VP"))
table(tmp$variable, tmp$VP)

tmp$site<-c(rep(1:10, each=456))
tmp$rating<-rep(rep(c("aesthetic_int", "usability_50", "usability_500", "usability_10000", "solution", "usability_inter", "time", "usability_wwu"), each = 57), times=10)

#table(tmp$variable, tmp$site)
#table(tmp$variable, tmp$rating)

data_2<-reshape(tmp[,c(1, 3:5)], direction="wide", idvar = c("VP","site"), timevar="rating")
names(data_2)<-c("vp", "site", "aesthetic_int", "rating_50", "rating_500", "rating_10000", "solution", "rating_inter", "time", "usability_wwu")

data_2$solution[data_2$solution!= 1]<-0
attach(data_2)

#
# Analysis
#

data_3<-aggregate(data_2, by=list(site), function(x){mean(x, na.rm=TRUE)})
data_4<-aggregate(data_2[data_2$solution == 1,], by=list(site[data_2$solution == 1]), function(x){mean(x, na.rm=TRUE)})

names(data_3)

m_sd<-function(x){cbind(mean(x, na.rm=TRUE), sd(x, na.rm=TRUE))}
m_sd(data_3$rating_50)
m_sd(data_3$rating_500)
m_sd(data_3$rating_1000)
m_sd(data_3$rating_inter)

data_anova<-melt(data_3[,c(3, 5:7)], id="site")
mod_1<-aov(value ~ variable + Error(site/variable), data=data_anova)
summary(mod_1)


# Analysis 0: Bias
cor.test(data_3$rating_50, data_3$usability_wwu)
cor.test(data_3$rating_500, data_3$usability_wwu)
cor.test(data_3$rating_1000, data_3$usability_wwu)
cor.test(data_3$rating_inter, data_3$usability_wwu)

# Analysis 1: Correlations
names(data_3)
cor.test(data_3$rating_50, data_3$rating_500)
cor.test(data_3$rating_50, data_3$rating_10000)
cor.test(data_3$rating_50, data_3$usability_wwu)
cor.test(data_3$rating_50, data_3$rating_10000)

cor.test(data_3$rating_500, data_3$rating_10000)
cor.test(data_3$rating_500, data_3$rating_inter)
cor.test(data_3$rating_10000, data_3$rating_inter)

cor.test(data_3$rating_500, data_3$solution)
cor.test(data_3$rating_1000, data_3$solution)
cor.test(data_3$rating_inter, data_3$solution)

cor.test(data_3$usability_wwu, data_3$solution)
cor.test(data_3$solution, data_3$aesthetic_int)

# hier nur für die Zeit nur die richtigen
cor.test(data_4$rating_50, data_4$time)
cor.test(data_4$rating_500, data_4$time)
cor.test(data_4$rating_1000, data_4$time)
cor.test(data_4$rating_inter, data_4$time)
cor.test(data_4$aesthetic_int, data_4$time)

cor.test(data_3$rating_50, data_3$usability_wwu)
cor.test(data_3$rating_500, data_3$usability_wwu)
cor.test(data_3$rating_1000, data_3$usability_wwu)
cor.test(data_3$rating_inter, data_3$usability_wwu)

cor.test(data_3$rating_50, data_3$aesthetic_int)
cor.test(data_3$rating_500, data_3$aesthetic_int)
cor.test(data_3$rating_1000, data_3$aesthetic_int)
cor.test(data_3$rating_inter, data_3$aesthetic_int)


# Analysis 2: Individual level

probs<-unique(vp)
res_50<-rep(NA, length(probs))
res_500<-rep(NA, length(probs))
res_10000<-rep(NA, length(probs))
res_inter<-rep(NA, length(probs))
res_wwu<-rep(NA, length(probs))

for(i in 1:length(probs)){
  dat_x<-data_2[data_2$solution ==1 & data_2$vp==probs[i],]
  try(res_50[i]<-cor.test(dat_x$time, dat_x$rating_50)$estimate[[1]])
  try(res_500[i]<-cor.test(dat_x$time, dat_x$rating_500)$estimate[[1]])
  try(res_10000[i]<-cor.test(dat_x$time, dat_x$rating_10000)$estimate[[1]])
  try(res_inter[i]<-cor.test(dat_x$time, dat_x$rating_inter)$estimate[[1]])
  try(res_wwu[i]<-cor.test(dat_x$time, dat_x$usability_wwu)$estimate[[1]])
}
cors<-data.frame(probs,res_50, res_500, res_10000, res_inter, res_wwu)
tmp<-melt(cors, id="probs")

fig_1<-ggplot(tmp, aes(x=variable, y=value, fill = variable)) +
  geom_boxplot()+
  geom_point(position=position_jitter(width=0.1, height=0), alpha=0.5) +
  geom_hline(yintercept = 0, linetype=2) +
  labs(title="Correlations between ratings and performance [task duration] at the individual level", x="Subjective usability rating", y="Correlationcoefficient [r]") +
  scale_x_discrete(labels=c("Expected U. \n 50ms", "Expected U. \n 500ms", "Expected U. \n 10.000ms", "Experienced U. \n single item", "Experienced U. \n questionnaire")) +
  guides(fill=FALSE) +
  theme_bw()+
  theme(axis.text=element_text(size=16))

ggsave("fig_1_individuals.tiff", fig_1, width=10, height=6, dpi=300)
ggsave("fig_1_individuals.png", fig_1, width=10, height=6, dpi=300)


# Solution
res_50<-rep(NA, length(probs))
res_500<-rep(NA, length(probs))
res_10000<-rep(NA, length(probs))
res_inter<-rep(NA, length(probs))
res_wwu<-rep(NA, length(probs))
table(data_2$vp, data_2$solution)
for(i in 1:length(probs)){
  dat_x<-data_2[data_2$vp==probs[i],]
  try(res_50[i]<-cor.test(dat_x$solution, dat_x$rating_50)$estimate[[1]])
  try(res_500[i]<-cor.test(dat_x$solution, dat_x$rating_500)$estimate[[1]])
  try(res_10000[i]<-cor.test(dat_x$solution, dat_x$rating_10000)$estimate[[1]])
  try(res_inter[i]<-cor.test(dat_x$solution, dat_x$rating_inter)$estimate[[1]])
  try(res_wwu[i]<-cor.test(dat_x$solution, dat_x$usability_wwu)$estimate[[1]])
}
cors_solution<-data.frame(probs,res_50, res_500, res_10000, res_inter, res_wwu)
tmp_solution<-melt(cors_solution, id="probs")
names(data_2)
fig_2<-ggplot(tmp_solution, aes(x=variable, y=value, fill = variable)) +
  geom_boxplot()+
  geom_point(position=position_jitter(width=0.1, height=0), alpha=0.5) +
  geom_hline(yintercept = 0, linetype=2) +
  labs(title="Correlations between ratings and performance [task completion] at the individual level", x="Subjective usability rating", y="Correlationcoefficient [r]") +
  scale_x_discrete(labels=c("Expected U. \n 50ms", "Expected U. \n 500ms", "Expected U. \n 10.000ms", "Experienced U. \n single item", "Experienced U. \n questionnaire")) +
  guides(fill=FALSE) +
  theme(axis.text=element_text(size=14)) +
  theme_bw() +
  theme(axis.text=element_text(size=16))


ggsave("fig_2_individuals_solution.tiff", fig_2, width=10, height=6, dpi=300)
ggsave("fig_2_individuals_solution.png", fig_2, width=10, height=6, dpi=300)
